@@ -15,10 +15,6 @@ import sys
 import threading
 
 import numpy
-# NumPy's behavior sometimes changes with versioning, especially in regard as 
-# to when ints are cast to floats.
-from packaging.version import parse, Version
-_np_version_forbids_neg_powint = parse(numpy.__version__) > Version('1.12.0b1')
 
 # Declare a double type that does not exist in Python space
 double = numpy.double
@@ -39,9 +35,8 @@ scalar_constant_types = tuple(scalar_constant_types)
 
 from numexpr import interpreter
 
-class Expression(object):
-    def __init__(self):
-        object.__init__(self)
+
+class Expression():
 
     def __getattr__(self, name):
         if name.startswith('_'):
@@ -142,6 +137,8 @@ def bestConstantType(x):
     # a float (32-bit) array with a double (64-bit) constant.
     if isinstance(x, double):
         return double
+    if isinstance(x, numpy.float32):
+        return float
     if isinstance(x, (int, numpy.integer)):
         # Constants needing more than 32 bits are always
         # considered ``long``, *regardless of the platform*, so we
@@ -156,7 +153,7 @@ def bestConstantType(x):
             y = converter(x)
         except Exception as err:
             continue
-        if y == x:
+        if y == x or numpy.isnan(y):
             return converter
 
 
@@ -273,18 +270,13 @@ def rtruediv_op(a, b):
 
 @ophelper
 def pow_op(a, b):
-    if (_np_version_forbids_neg_powint and
-        b.astKind in ('int', 'long') and
-        a.astKind in ('int', 'long') and
-        numpy.any(b.value < 0)):
 
-        raise ValueError(
-            'Integers to negative integer powers are not allowed.')
-
-    if allConstantNodes([a, b]):
-        return ConstantNode(a.value ** b.value)
     if isinstance(b, ConstantNode):
         x = b.value
+        if (    a.astKind in ('int', 'long') and
+                b.astKind in ('int', 'long') and x < 0) :
+            raise ValueError(
+                'Integers to negative integer powers are not allowed.')
         if get_optimization() == 'aggressive':
             RANGE = 50  # Approximate break even point with pow(x,y)
             # Optimize all integral and half integral powers in [-RANGE, RANGE]
@@ -315,7 +307,8 @@ def pow_op(a, b):
                 if r is None:
                     r = OpNode('ones_like', [a])
                 if x < 0:
-                    r = OpNode('div', [ConstantNode(1), r])
+                    # Issue #428
+                    r = truediv_op(ConstantNode(1), r)
                 return r
         if get_optimization() in ('moderate', 'aggressive'):
             if x == -1:
@@ -333,6 +326,7 @@ def pow_op(a, b):
     return OpNode('pow', [a, b])
 
 # The functions and the minimum and maximum types accepted
+numpy.expm1x = numpy.expm1
 functions = {
     'copy': func(numpy.copy),
     'ones_like': func(numpy.ones_like),
@@ -380,7 +374,7 @@ functions = {
 }
 
 
-class ExpressionNode(object):
+class ExpressionNode():
     """
     An object that represents a generic number object.
 
@@ -390,7 +384,6 @@ class ExpressionNode(object):
     astType = 'generic'
 
     def __init__(self, value=None, kind=None, children=None):
-        object.__init__(self)
         self.value = value
         if kind is None:
             kind = 'none'
@@ -478,7 +471,7 @@ class VariableNode(LeafNode):
         LeafNode.__init__(self, value=value, kind=kind)
 
 
-class RawNode(object):
+class RawNode():
     """
     Used to pass raw integers to interpreter.
     For instance, for selecting what function to use in func1.
@@ -504,7 +497,7 @@ class ConstantNode(LeafNode):
     def __init__(self, value=None, children=None):
         kind = getKind(value)
         # Python float constants are double precision by default
-        if kind == 'float':
+        if kind == 'float' and isinstance(value, float):
             kind = 'double'
         LeafNode.__init__(self, value=value, kind=kind)
 
