@@ -19,10 +19,14 @@
 #define BLOCK_SIZE1 1024
 #endif
 
-// The default threadpool size. It's prefer that the user set this via an 
+// The default threadpool size. It's prefer that the user set this via an
 // environment variable, "NUMEXPR_MAX_THREADS"
 #define DEFAULT_MAX_THREADS 64
 
+// Remove dependence on NPY_MAXARGS, which would be a runtime constant instead of compiletime
+// constant. If numpy raises NPY_MAXARGS, we should notice and raise this as well
+#define NE_MAXARGS 64
+
 #if defined(_WIN32)
   #include "win32/pthread.h"
   #include <process.h>
